
; Monitorprogramm fuer CPD5

		TITLE	CPD5DEF

		.Z80


; **********************************************************
;         Vereinbarungsteil fuer CP/M 2.2
; **********************************************************


Monitor		EQU	1


BIOSSTACK	EQU	0FFFEH


TPA		EQU	0100H

;CBIOS fuer CP/M 2.2
;

IF Monitor
BIOSBASE	EQU	0F000H
ELSE
BIOSBASE	EQU	0F400H
ENDIF


BIOSLEN		EQU	0FFFFH-BIOSBASE+1	; 4096 Byte
;
BDOSLEN		EQU	0E00H			;
BDOSBASE    	EQU	BIOSBASE-BDOSLEN	; 
;
CCPLEN		EQU	0800H			; 
CCPBASE     	EQU	BDOSBASE-CCPLEN		; 	
;
EEROMCCP	EQU	0100H
EEPROMBDOS	EQU	EEROMCCP+CCPLEN	; 0900H

;
USERLW		EQU	4	;Laufwerksregister
IOBYTE		EQU	3	;Intel I/O-Byte
;
SBDOS		EQU	BDOSBASE+6
SCCP		EQU	CCPBASE+03H

RAMSTART	EQU	BIOSBASE



; **********************************************************
;         Vereinbarungsteil fuer den Bus-Controller
; **********************************************************


; Befehlscode fuer Z80CALL
BC_CONIN	EQU	1	; Console In
BC_CONST	EQU	2	; Console Status
BC_CONOUT	EQU	3	; Console Out
BC_LIST		EQU	4	; Ausgabe an Drucker
BC_COPY_BDOS	EQU	5	; COPY BDOS
BC_COPY_CCP	EQU	6	; COPY CCP
BC_READ_SEC	EQU	7	; Sektor lesen
BC_WRITE_SEC	EQU	8	; Sektor schreiben
BC_TRACE_Z80	EQU	9	; WAIT-Trace aktivieren (ab hier)
BC_SET_TIME	EQU	10	; setzt die Zeit im SCB nach der Uhrzeit vom PC






; **********************************************************
;         Vereinbarungsteil fuer die Hardware
; **********************************************************



FRQ		EQU	6			; Frequenz in MHz

	; 
	;---Kanaladressen---

; A0 = CONTSEL,  A1 = PORTSEL,  A2 = /CE-PIO1,  A3 = /CE-PIO2

PIO1AD		EQU     11111000B		;PIO 1 A Daten
PIO1AC		EQU     11111001B		;PIO 1 A Kommandos

PIO1BD		EQU     11111010B		;PIO 1 B Daten
PIO1BC		EQU     11111011B		;PIO 1 B Kommandos

PIO2AD		EQU     11110100B		;PIO 2 A Daten
PIO2AC		EQU     11110101B		;PIO 2 A Kommandos

PIO2BD		EQU     11110110B		;PIO 2 B Daten
PIO2BC		EQU     11110111B		;PIO 2 B Kommandos


; --------------------------------------------
;
; Funktionale Bezeichnung der Ports
;
D_SYS_PORT	EQU	PIO1AD
C_SYS_PORT	EQU	PIO1AC
;
D_ITP2_CON1	EQU	PIO1BD
C_ITP2_CON1	EQU	PIO1BC
;
D_ITP2_CON2	EQU	PIO2AD
C_ITP2_CON2	EQU	PIO2AC
;
D_ITP2_CON3	EQU	PIO2BD
C_ITP2_CON3	EQU	PIO2BC
;

ANZ_PORT	EQU	3


; --------------------------------------------
;
; Bitmaske - alles Eingaenge
BITMSKAE	EQU	11111111B
; Bitmaske - alles Ausgaenge
BITMSKAA	EQU	00000000B



; ============================================
;
;   Kommandowerte der PIOs
;
; ============================================
;
;
; PIO 1 - Port A - Initialwert der Kommandos
;
; A0 = /Z80CALL  = 0 = Low aktiv  (Ausgang)
; A1 = /Z80AK    = 1 =            (Eingang)
; A2 = /Z80WA    = 0 = Low aktiv  (Ausgang)
; A3 = Z80LEDRT  = 0 = High aktiv (Ausgang)
; A4 = N.N.
; A5 = N.N.
; A6 = N.N.
; A7 = N.N.
;
; Ausgang=0 / Eingang = 1  
;                       EEEEAAEA
C_SYS_IW	EQU	11110010B	; Initialwert-Kommandos Systemport

; --------------------------------------------
;
; PIO 1 - Port B - Initialwert der Kommandos
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 1 - Eingang
; B1 = D1     = 1 - Eingang
; B2 = D2     = 1 - Eingang
; B3 = D3     = 1 - Eingang 
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 1 - Eingang
; B7 = SRAC   = 1 - Eingang 

C_ITP2_IW	EQU 	11101111B	; Initialwert-Kommandos ITP2

; --------------------------------------------
;
; ITP2 Kommandos - Read-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 1 - Eingang
; B1 = D1     = 1 - Eingang
; B2 = D2     = 1 - Eingang
; B3 = D3     = 1 - Eingang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 1 - Eingang
; B7 = SRAC   = 0 - Ausgang 

C_ITP2_RD	EQU 	01101111B	; Read-Kommando ITP2	 

; --------------------------------------------
;
; ITP2 Kommandos - Write-Modus
;
; Bitmaske Port B - Initialisierung
; B0 = D0     = 0 - Ausgang
; B1 = D1     = 0 - Ausgang
; B2 = D2     = 0 - Ausgang
; B3 = D3     = 0 - Ausgang
; B4 = DDWR   = 0 - Ausgang
; B5 = DDAC   = 1 - Eingang
; B6 = SDEN   = 0 - Ausgang
; B7 = SRAC   = 1 - Eingang 

C_ITP2_WR	EQU 	10100000B	; Write-Kommando ITP2	




; ============================================
;
;   Datenwerte der PIOs
;
; ============================================
;
; PIO 1 - Port A - Initialwert der Daten des Ausgaberegisters
;
; A0 = /Z80CALL  = 1 = Low aktiv  (Ausgang)
; A1 = /Z80AK    = 0 = Low aktiv  (Eingang)
; A2 = /Z80WA    = 1 = Low aktiv  (Ausgang)
; A3 = Z80LEDRT  = 0 = High aktiv (Ausgang)
; A4 = N.N.
; A5 = N.N.
; A6 = N.N.
; A7 = N.N.
;                            
D_SYS_IW		EQU 	00000111B	; Initialwert-Daten Systemport


BIT_Z80CALL	EQU	0
BIT_Z80AK	EQU	1
BIT_Z80WA	EQU	2
BIT_LED_RT	EQU	3


; --------------------------------------------
;
; PIO 1 - Port B - Initialwert der Daten des Ausgaberegisters
;
; B0 = D0     = X = (Eingang)
; B1 = D1     = X = (Eingang)
; B2 = D2     = X = (Eingang)
; B3 = D3     = X = (Eingang)
; B4 = DDWR   = 1 = (Ausgang) High wie Widerstand
; B5 = DDAC   = 1 = (Eingang)
; B6 = SDEN   = 0 = (Eingang) SDEN inaktiv
; B7 = SRAC   = 0 = (Eingang) 

D_ITP2_IW	EQU 	00110000B	; Initialwert-Daten ITP2


BIT_ID0		EQU	0
BIT_ID1		EQU	1
BIT_ID2		EQU	2
BIT_ID3		EQU	3

BIT_DDWR	EQU	4
BIT_DDAC	EQU	5
BIT_SDEN	EQU	6
BIT_SRAC	EQU	7





; ============================================
;
;   Konstantentabellen fuer BIOS
;
; ============================================
;
;
RE_CONST	EQU	1		; Code fuer RECEIVE CONST 
RE_CONIN	EQU	2		; Code fuer RECEIVE CONIN 
SE_CONOUT	EQU	3		; Code fuer SEND CONOUT
RE_SECNT	EQU	4		; Code fuer RECEIVE SECTOR COUNT
RE_SECTOR	EQU	5		; Code fuer RECEIVE SECTOR
RE_RD_ISEC	EQU	6		; Code fuer RECEIVE READ IMAGE SECTOR
SE_WR_ISEC	EQU	7		; Code fuer SEND WRITE IMAGE SECTOR
SE_STD		EQU	8		; Code fuer SEND SECTOR, TRACK, DRIVE
SE_LIST		EQU	9		; Code fuer SEND LIST
RE_ERROR_CODE	EQU	10		; Code fuer RECEIVE ERROR CODE
RE_SAVE_RAM2FL	EQU	11		; Code fuer RECEIVE SAVE RAM-Floppy (RAM in FLASH brennen)
RE_COPY_FL2RAM	EQU	12		; Code fuer RECEIVE COPY RAM-Floppy (FLASH in RAM copieren)
SE_SECNT	EQU	14		; Code fuer SEND SECTOR COUNT
SE_SOUND	EQU	15		; Code fuer SEND SOUND


WHO_ARE_YOU	EQU	20		; Code fuer Abfrage der Funktionalitaet
					; des angeschlossenen Geraetes

; ============================================
;

DEVCODE_PC_CPM_EMU   EQU	2	; Code fuer PC-CP/M-Emulator
DEVCODE_KEYBOARD     EQU	3	; Code fuer Tastatur
DEVCODE_DISPLAY      EQU	4	; Code fuer LCD-Display
DEVCODE_RAMFLOPPY    EQU	5	; Code fuer RAM-Floppy
DEVCODE_CONINOUT     EQU        6       ; Code fuer Tastatur und Display
DEVCODE_SOUND        EQU        7       ; Code fuer Tonausgabe


; ============================================
;






















